==> tidyquant_0.5.9.tar.gz: tidyquant/R/global_vars.R <==
globalVariables(c("A",
                  "Q",
                  "X1",
                  "X2",
                  "category",
                  "date.downloaded",
                  "index.components",
                  "index.option",
                  "period",
                  "retrieve",
                  "type",
                  "value",
                  "x_fun",
                  "TTM",
                  "X",
                  "group",
                  "section",
                  "sub.section",
                  "adjusted",
                  "symbol..",
                  "data..",
                  "class..",
                  "Revenue USD Mil",
                  "Shares Mil",
                  "Operating Cash Flow USD Mil",
                  "Earnings Per Share USD",
                  "Price to Book",
                  "Price to Cash Flow",
                  "Price to Earnings",
                  "Price to Sales",
                  "Book Value Per Share * USD",
                  "Cash Flow Per Share USD",
                  "Revenue Per Share USD",
                  "Ask",
                  "Ask.Size" ,
                  "Average.Daily.Volume",
                  "Bid",
                  "Bid.Size",
                  "Book.Value",
                  "Change",
                  "Change.From.200.day.Moving.Average",
                  "Change.From.50.day.Moving.Average",
                  "Change.From.52.week.High",
                  "Change.From.52.week.Low",
                  "Change.in.Percent",
                  "Currency",
                  "Days.High",
                  "Days.Low",
                  "Days.Range",
                  "Dividend.Pay.Date",
                  "Dividend.per.Share",
                  "Dividend.Yield",
                  "EBITDA",
                  "EPS",
                  "EPS.Estimate.Current.Year",
                  "EPS.Estimate.Next.Quarter",
                  "EPS.Estimate.Next.Year",
                  "Ex.Dividend.Date",
                  "Float.Shares",
                  "High.52.week",
                  "Last.Trade.Date",
                  "Last.Trade.Price.Only",
                  "Last.Trade.Size",
                  "Last.Trade.With.Time",
                  "Low.52.week",
                  "Market.Capitalization",
                  "Moving.Average.200.day",
                  "Moving.Average.50.day",
                  "Name",
                  "Open",
                  "PE.Ratio",
                  "PEG.Ratio",
                  "Percent.Change.From.200.day.Moving.Average",
                  "Percent.Change.From.50.day.Moving.Average",
                  "Percent.Change.From.52.week.High",
                  "Percent.Change.From.52.week.Low",
                  "Previous.Close",
                  "Price.to.Book",
                  "Price.to.EPS.Estimate.Current.Year",
                  "Price.to.EPS.Estimate.Next.Year",
                  "Price.to.Sales",
                  "Range.52.week",
                  "Revenue",
                  "Shares.Outstanding",
                  "Short.Ratio",
                  "Stock.Exchange",
                  "Target.Price.1.yr.",
                  "Volume",
                  "IPOyear",
                  "LastSale",
                  "MarketCap",
                  "Sector",
                  "Symbol",
                  "company",
                  "industry",
                  "ipo.year",
                  "last.sale.price",
                  "market.cap",
                  "sector",
                  "symbol",
                  ".",
                  "df_mult",
                  "is.grouped_df",
                  "left_join",
                  "returns..",
                  "tibble",
                  "ungroup",
                  "weights..",
                  "portfolio",
                  "portfolio..",
                  "rowname",
                  'scale_color_manual',
                  'scale_fill_manual',
                  '%+replace%',
                  'theme_grey',
                  'theme',
                  'element_line',
                  "element_rect",
                  'rel',
                  "element_blank",
                  "element_text",
                  "margin",
                  "unit",
                  "assets",
                  "Weight",
                  "Identifier",
                  "Shares.Held",
                  "nested.col"
                  ))

==> tidyquant_1.0.0.tar.gz: tidyquant/R/global_vars.R <==
globalVariables(c("A",
                  "Q",
                  "X1",
                  "X2",
                  "category",
                  "date.downloaded",
                  "index.components",
                  "index.option",
                  "period",
                  "retrieve",
                  "type",
                  "value",
                  "x_fun",
                  "TTM",
                  "X",
                  "group",
                  "section",
                  "sub.section",
                  "adjusted",
                  "symbol..",
                  "data..",
                  "class..",
                  "Revenue USD Mil",
                  "Shares Mil",
                  "Operating Cash Flow USD Mil",
                  "Earnings Per Share USD",
                  "Price to Book",
                  "Price to Cash Flow",
                  "Price to Earnings",
                  "Price to Sales",
                  "Book Value Per Share * USD",
                  "Cash Flow Per Share USD",
                  "Revenue Per Share USD",
                  "Ask",
                  "Ask.Size" ,
                  "Average.Daily.Volume",
                  "Bid",
                  "Bid.Size",
                  "Book.Value",
                  "Change",
                  "Change.From.200.day.Moving.Average",
                  "Change.From.50.day.Moving.Average",
                  "Change.From.52.week.High",
                  "Change.From.52.week.Low",
                  "Change.in.Percent",
                  "Currency",
                  "Days.High",
                  "Days.Low",
                  "Days.Range",
                  "Dividend.Pay.Date",
                  "Dividend.per.Share",
                  "Dividend.Yield",
                  "EBITDA",
                  "EPS",
                  "EPS.Estimate.Current.Year",
                  "EPS.Estimate.Next.Quarter",
                  "EPS.Estimate.Next.Year",
                  "Ex.Dividend.Date",
                  "Float.Shares",
                  "High.52.week",
                  "Last.Trade.Date",
                  "Last.Trade.Price.Only",
                  "Last.Trade.Size",
                  "Last.Trade.With.Time",
                  "Low.52.week",
                  "Market.Capitalization",
                  "Moving.Average.200.day",
                  "Moving.Average.50.day",
                  "Name",
                  "Open",
                  "PE.Ratio",
                  "PEG.Ratio",
                  "Percent.Change.From.200.day.Moving.Average",
                  "Percent.Change.From.50.day.Moving.Average",
                  "Percent.Change.From.52.week.High",
                  "Percent.Change.From.52.week.Low",
                  "Previous.Close",
                  "Price.to.Book",
                  "Price.to.EPS.Estimate.Current.Year",
                  "Price.to.EPS.Estimate.Next.Year",
                  "Price.to.Sales",
                  "Range.52.week",
                  "Revenue",
                  "Shares.Outstanding",
                  "Short.Ratio",
                  "Stock.Exchange",
                  "Target.Price.1.yr.",
                  "Volume",
                  "IPOyear",
                  "LastSale",
                  "MarketCap",
                  "Sector",
                  "Symbol",
                  "company",
                  "industry",
                  "ipo.year",
                  "last.sale.price",
                  "market.cap",
                  "sector",
                  "symbol",
                  ".",
                  "df_mult",
                  "is.grouped_df",
                  "left_join",
                  "returns..",
                  "tibble",
                  "ungroup",
                  "weights..",
                  "portfolio",
                  "portfolio..",
                  "rowname",
                  'scale_color_manual',
                  'scale_fill_manual',
                  '%+replace%',
                  'theme_grey',
                  'theme',
                  'element_line',
                  "element_rect",
                  'rel',
                  "element_blank",
                  "element_text",
                  "margin",
                  "unit",
                  "assets",
                  "Weight",
                  "Identifier",
                  "Shares.Held",
                  "nested.col",
                  "comma_loc",
                  "count_parenthesis",
                  "holidays",
                  "is_function",
                  "key",
                  "var_text",
                  "weekday",
                  "adjClose",
                  "high",
                  "low",
                  "ticker",
                  "volume"
                  ))
